@@ -156,15 +156,19 @@ class HookRegistry:
             v._rfm_attach = ['post_setup']
             self.__hooks.add(Hook(v))
 
-    def update(self, hooks, *, denied_hooks=None):
+    def update(self, other, *, denied_hooks=None):
         '''Update the hook registry with the hooks from another hook registry.
 
         The optional ``denied_hooks`` argument takes a set of disallowed
         hook names, preventing their inclusion into the current hook registry.
         '''
+
+        assert isinstance(other, HookRegistry)
         denied_hooks = denied_hooks or set()
-        for h in hooks:
+        for h in other:
             if h.__name__ not in denied_hooks:
+                # Hooks in `other` override ours
+                self.__hooks.discard(h)
                 self.__hooks.add(h)
 
     def __repr__(self):
