@@ -36,7 +36,8 @@ def getscheduler(name):
 
 # Import the schedulers modules to trigger their registration
 import reframe.core.schedulers.local   # noqa: F401, F403
-import reframe.core.schedulers.slurm   # noqa: F401, F403
+import reframe.core.schedulers.lsf     # noqa: F401, F403
+import reframe.core.schedulers.oar     # noqa: F401, F403
 import reframe.core.schedulers.pbs     # noqa: F401, F403
 import reframe.core.schedulers.sge     # noqa: F401, F403
-import reframe.core.schedulers.torque  # noqa: F401, F403
+import reframe.core.schedulers.slurm   # noqa: F401, F403
