@@ -17,6 +17,8 @@ import sys
 import types
 import weakref
 
+import reframe
+
 from collections import UserDict
 from . import typecheck as typ
 
@@ -81,7 +83,7 @@ def import_module_from_file(filename, force=False):
         filename = os.path.join(filename, '__init__.py')
 
     # Express filename relative to reframe
-    rel_filename = os.path.relpath(filename, sys.path[0])
+    rel_filename = os.path.relpath(filename, reframe.INSTALL_PREFIX)
     module_name = _get_module_name(rel_filename)
     if rel_filename.startswith('..'):
         # We cannot use the standard Python import mechanism here, because the
